]> git.armaanb.net Git - dwmblocks.git/commitdiff
Changed delimeter to accept multiple characters.
authorAidan <torrinfail@gmail.com>
Mon, 4 Nov 2019 22:34:34 +0000 (15:34 -0700)
committerAidan <torrinfail@gmail.com>
Mon, 4 Nov 2019 22:34:34 +0000 (15:34 -0700)
blocks.h
dwmblocks.c

index 31e98af236e3d9b5578984b94c03dfa21bb2a2ff..3493ce14cfa874f08ac1ec137254c077db3c67a4 100644 (file)
--- a/blocks.h
+++ b/blocks.h
@@ -16,5 +16,5 @@ static const Block blocks[] = {
        {"", "~/bin/statusbar/clock",                                           5,              0},
 };
 
-//sets delimeter between status commands. NULL character ('\0') means no delimeter.
-static char delim = '|';
+//sets delimeter between status commands. Empty string ("") means no delimeter.
+static char* delim = "|";
index 2db3489144bb57c5bccb6e96d53113ac6c3e5db4..76e7377a9a84f233e78a69b714305ffa22c7e9f3 100644 (file)
@@ -56,13 +56,20 @@ void getcmd(const Block *block, char *output)
                return;
        //int N = strlen(output);
        char c;
-       int i = strlen(block->icon);
+       int sl;
+       int i = sl = strlen(block->icon);
        while((c = fgetc(cmdf)) != EOF)
                output[i++] = c;
-       if (delim != '\0' && --i)
-               output[i++] = delim;
-       output[i++] = '\0';
        pclose(cmdf);
+       if (i == sl) { //return empty string if command has no output
+               output[0] = '\0';
+               return;
+       }
+       if (delim[0] != '\0' && --i)
+               for (int j = 0; delim[j]; j++)
+                       output[i++] = delim[j];
+       else 
+               output[--i] = '\0';
 }
 
 void getcmds(int time)
@@ -104,7 +111,8 @@ void getstatus(char *str)
        {       
                strcpy(str + j, statusbar[i]);
        }
-       str[--j] = '\0';
+       for (int i = 0; delim[i]; i++)
+               str[--j] = '\0';
 
 }
 
@@ -159,7 +167,7 @@ int main(int argc, char** argv)
        for(int i = 0; i < argc; i++)
        {       
                if (!strcmp("-d",argv[i]))
-                       delim = argv[++i][0];
+                       delim = argv[++i];
        }
        signal(SIGTERM, termhandler);
        signal(SIGINT, termhandler);